# Spectra Manipulator

TODO

Installation Methods
--------------------

* From PyPI:
   * `pip install spectramanipulator`
    

### Used packages

* pyqtgraph
* lmfit
* matplotlib
* PyQt5
* qtconsole
* numba
* requests
* winshell

First Launch
--------------------

* Run with `python -m spectramanipulator`
  
For Windows users (*optional*)
  * Associate project files (in Windows registry) `python -m spectramanipulator --associate_files`
  * Remove association (in Windows registry) `python -m spectramanipulator --remove_association`
  * Create desktop shortcut `python -m spectramanipulator --create_desktop_shortcut`

Updates
-----------
* From terminal:
  * `pip install spectramanipulator --upgrade`
* In running program: 
  * In the MenuBar, Help → Check for updates...